"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useTooltipTrigger = useTooltipTrigger;
var _interactions = require("@react-aria/interactions");
var _react = require("react");
var _utils = require("@react-aria/utils");
var _focus = require("@react-aria/focus");
var _interactions2 = require("@react-native-aria/interactions");
/**
 * Provides the behavior and accessibility implementation for a tooltip trigger, e.g. a button
 * that shows a description when focused or hovered.
 */
function useTooltipTrigger(props, state, ref) {
  let {
    isDisabled,
    trigger
  } = props;
  let tooltipId = (0, _utils.useId)();
  let isHovered = (0, _react.useRef)(false);
  let isFocused = (0, _react.useRef)(false);
  let handleShow = () => {
    if (isHovered.current || isFocused.current) {
      state.open(isFocused.current);
    }
  };
  let handleHide = () => {
    if (!isHovered.current && !isFocused.current) {
      state.close();
    }
  };
  (0, _react.useEffect)(() => {
    let onKeyDown = e => {
      if (ref && ref.current) {
        // Escape after clicking something can give it keyboard focus
        // dismiss tooltip on esc key press
        if (e.key === 'Escape') {
          state.close();
        }
      }
    };
    if (state.isOpen) {
      document.addEventListener('keydown', onKeyDown, true);
      return () => {
        document.removeEventListener('keydown', onKeyDown, true);
      };
    }
    return () => {};
  }, [ref, state]);
  let onHoverStart = () => {
    if (trigger === 'focus') {
      return;
    }
    // In chrome, if you hover a trigger, then another element obscures it, due to keyboard
    // interactions for example, hover will end. When hover is restored after that element disappears,
    // focus moves on for example, then the tooltip will reopen. We check the modality to know if the hover
    // is the result of moving the mouse.
    if ((0, _interactions.getInteractionModality)() === 'pointer') {
      isHovered.current = true;
    } else {
      isHovered.current = false;
    }
    handleShow();
  };
  let onHoverEnd = () => {
    if (trigger === 'focus') {
      return;
    }
    // no matter how the trigger is left, we should close the tooltip
    isFocused.current = false;
    isHovered.current = false;
    handleHide();
  };
  let onPressStart = () => {
    // no matter how the trigger is pressed, we should close the tooltip
    isFocused.current = false;
    isHovered.current = false;
    handleHide();
  };
  let onFocus = () => {
    let isVisible = (0, _interactions.isFocusVisible)();
    if (isVisible) {
      isFocused.current = true;
      handleShow();
    }
  };
  let onBlur = () => {
    isFocused.current = false;
    isHovered.current = false;
    handleHide();
  };
  let {
    hoverProps
  } = (0, _interactions2.useHover)({
    isDisabled,
    onHoverStart,
    onHoverEnd
  }, ref);
  let {
    pressProps
  } = (0, _interactions2.usePress)({
    onPressStart
  });
  let {
    focusableProps
  } = (0, _focus.useFocusable)({
    isDisabled,
    onFocus,
    onBlur
  }, ref);
  return {
    triggerProps: {
      'aria-describedby': state.isOpen ? tooltipId : undefined,
      //@ts-ignore
      ...(0, _utils.mergeProps)(focusableProps, hoverProps, pressProps)
    },
    tooltipProps: {
      id: tooltipId
    }
  };
}
//# sourceMappingURL=useTooltipTrigger.web.js.map